package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!````&I@$"#0```!4L@```````#0`(``)
M`"@`'0`<``8````T````-(`$"#2`!`@@`0``(`$```4````$`````P```%0!
M``!4@00(5($$"!,````3````!`````$````!``````````"`!`@`@`0(A*P`
M`(2L```%`````!````$```#@K@``X#X%".`^!0@X`@``E!(```8`````$```
M`@```.RN``#L/@4([#X%"!`!```0`0``!@````0````$````:`$``&B!!`AH
M@00(1````$0````$````!````%#E=&28G@``F!X%")@>!0C<````W`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DX*X`
M`.`^!0C@/@4((`$``"`!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`O9?+N,XZ$K1#&#A=4XGX+JUUM34E````00````@````(`````!P0!"5`
M!((X`4`!H(8!B,`!``)+*`0I.*(R1XH$#`A!````0P``````````````````
M`$4```!'````2`````````!)````2@```$P```!-````3@```$\`````````
M40``````````````4@```%,```!6``````````````!7````60```%H```!<
M`````````%X```!@````````````````````8@```&,`````````R-6R<5GH
M[>S.WD<MH^#[2>K3[PZGW:-K+\6;MMO-XYZ'^9R!5J2;EFL)0]8Y\HL<#3J7
M"\6)!9`,%.*>B0=PTR'_Y`X+BA!7Q+F<0&I_FGRS`8MO?ZF<FV[%WQ_9<5@<
MN^.2?*Q+X\#59-1\X*<""C-BV^UZ\$IK9Z_,9D)%U>SC1\8!P^4_+/+;TQWZ
MH6Q@N8WQ#@````````````````````##`@`````````````2````:0,`````
M````````$@````<"`````````````!(````1```````````````@````Y0,`
M````````````$@```%H#`````````````!(````9`0`````````````2````
MW@(`````````````$@```+P``````````````!(```#*`@`````````````2
M````F```````````````$@```!0!`````````````!(```"!`@``````````
M```2````%P,`````````````$@```)("`````````````!(```!O`0``````
M```````2````)P,`````````````$@```!X#`````````````!(````]`0``
M```````````2````R@``````````````$@```+D!`````````````!(```!0
M`@`````````````2````_P$`````````````$@```*X"`````````````!(`
M``"F`0`````````````2````GP(`````````````$@```+(!````````````
M`!(```!+`0`````````````2````+@,`````````````$@```"T`````````
M`````"````!B`@`````````````2````.P,`````````````$@```'@`````
M`````````!(```"\`@`````````````2````<`,`````````````$@```/@!
M`````````````!(```"G```````````````2````9`$`````````````$@``
M`)D"`````````````!(```!O`@`````````````2````(`(`````````````
M$@```*<"`````````````!(```!J```````````````2````'@$`````````
M````$@```.4"`````````````!(```";`0`````````````2````^```````
M````````$@```&(#`````````````!(```"U`@`````````````2````?0$`
M````````````$@```#P``````````````"````#<```````````````2````
M6P$`````````````$@```$(#`````````````!(```#0`@`````````````2
M````4```````````````(````&<"`````````````!(````&`P``````````
M```2````#`(`````````````$@```/,"`````````````!(````Q`@``````
M```````2````>`(`````````````$@```/X"`````````````!(```!,`P``
M```````````2````*@$``("4!`@`````$@```%T$``"HW00(!````!$`$``3
M!```0,P$"&$,```2``X`9`0``+#(!`BW`0``$@`.`+P#``"4W00(`````!(`
M#P"$`P``($$%"`0````A`!H`P@,``,#%!`@%````$@`.`$,$```PW00(70``
M`!(`#@"'````,)4$"``````2````"0$``#!!!0@$````$0`:`"`$```(004(
M`````!``&0`0`P``*$$%"`0````1`!H`(@0```A!!0@`````(``9`(,#```@
M004(!````"$`&@"R`P``D-T$"`(````2``X`4P0``!1!!0@$````$0`9`'D$
M``#0Q00(N`$``!(`#@#K````-$$%"`$````1`!H`@@,``"!!!0@$````$0`:
M`'T#```0E@0("@(``!(`#@"8!```<,H$"&D````2``X`TP,``.#*!`@D````
M$@`.`.X#``"`W`0(=````!(`#@"A`P``&$$%"``````0`!H`K0,``'11!0@`
M````$``:`$$"``"LW00(!````!$`$`"F!```L-@$",X#```2``X`+00```#%
M!`BQ````$@`.`"8$```:F`0(`````!(`#@"+`0``D)($"``````2````!P0`
M`,#'!`CG````$@`.`)H#```8004(`````!``&0#Z`P``D,<$""T````2``X`
M<00``(#$!`@G````$@`.`,0!```X004($P```!$`&@"&!```$,L$""8!```2
M``X`<P0``-R1!`@`````$@`+``!L:6)P97)L+G-O+C4N,C(`7TE435]D97)E
M9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%]*=E]296=I<W1E
M<D-L87-S97,`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T
M97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS
M=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L
M7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R
M;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E
M=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E
M=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?
M879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E
M<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``;&EB9&PN<V\N
M,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`&]P96XV-`!L<V5E:S8T`')E
M860`<'1H<F5A9%]G971S<&5C:69I8P!?7V5R<FYO7VQO8V%T:6]N`&-L;W-E
M`&QI8F,N<V\N-@!?24]?<W1D:6Y?=7-E9`!?7W)E9VES=&5R7V%T9F]R:P!E
M>&ET`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I
M;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<G1O:P!S
M=')L96X`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R
M;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`
M9V5T=6ED`')E861L:6YK`&5X96-V<`!?7VUE;6-P>5]C:&L`<W1R8VAR`')E
M861D:7(V-`!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?
M7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`;&EB8W)Y<'0N<V\N,0!?961A
M=&$`7U]B<W-?<W1A<G0`7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E
M;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU
M<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T
M85]S=&%R=`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET
M`&UY7W!A<E]P;`!?9G!?:'<`<&%R7VEN:71?96YV`'AS7VEN:70`<&%R7V9I
M;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT
M97)N86QS7U!!4E]"3T]4`$=,24)#7S(N,@!'3$E"0U\R+C``1TQ)0D-?,BXS
M+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXT`````@`"``,````"``(``@`"````
M`@``````!``"``(````"``(`````````!0`&``(````"``(````'`````@`"
M`````@`"``8```````(``@`#``(```````<```````(``@````````````@`
M!P````(`"``#``@``P`"``(`!P````$``0`!``$``@`!``$```````$``@`!
M``(``0`!``$````"``$``0`!``$``0`!``$``0`!``$````!``$``0`!````
M`0`!`````0`"`.@!```0````,````!)I:0T```8`O`0``!`````0:6D-```#
M`,8$`````````0`%`#<"```0`````````!)I:0T```@`O`0``!````!T&6D)
M```'`-`$```0````<AEI"0``!0#<!```$````!1I:0T```0`Z`0``!`````0
M:6D-```"`,8$````````_#\%"`8>```@004(!5,``"A!!0@%3```,$$%"`5*
M```T004(!5(``#A!!0@%8P``#$`%"`<!```00`4(!P(``!1`!0@'`P``&$`%
M"`<%```<0`4(!P8``"!`!0@'!P``)$`%"`<(```H0`4(!PD``"Q`!0@'7@``
M,$`%"`<*```T0`4(!PL``#A`!0@'#```/$`%"`<-``!`0`4(!PX``$1`!0@'
M#P``2$`%"`<0``!,0`4(!Q$``%!`!0@'$@``5$`%"`<3``!80`4(!Q0``%Q`
M!0@'%0``8$`%"`<6``!D0`4(!Q<``&A`!0@'&```;$`%"`<9``!P0`4(!QH`
M`'1`!0@'&P``>$`%"`<<``!\0`4(!QT``(!`!0@''P``A$`%"`<@``"(0`4(
M!R$``(Q`!0@'(@``D$`%"`<C``"40`4(!R0``)A`!0@')0``G$`%"`<F``"@
M0`4(!R<``*1`!0@'*```J$`%"`=!``"L0`4(!RD``+!`!0@'*@``M$`%"`<K
M``"X0`4(!RP``+Q`!0@'+0``P$`%"`<N``#$0`4(!R\``,A`!0@',```S$`%
M"`<Q``#00`4(!S(``-1`!0@'20``V$`%"`<T``#<0`4(!S4``.!`!0@'-@``
MY$`%"`<W``#H0`4(!SD``.Q`!0@'.@``\$`%"`<[``#T0`4(!SP``/A`!0@'
M/0``_$`%"`<^````004(!S\```1!!0@'0```4X/L".A;!@``@<,;K@``BX/\
M____A<!T!>@&!```@\0(6\,`_S4$0`4(_R4(0`4(`````/\E#$`%"&@`````
MZ>#_____)1!`!0AH"````.G0_____R440`4(:!````#IP/____\E&$`%"&@8
M````Z;#_____)1Q`!0AH(````.F@_____R4@0`4(:"@```#ID/____\E)$`%
M"&@P````Z8#_____)2A`!0AH.````.EP_____R4L0`4(:$````#I8/____\E
M,$`%"&A(````Z5#_____)31`!0AH4````.E`_____R4X0`4(:%@```#I,/__
M__\E/$`%"&A@````Z2#_____)4!`!0AH:````.D0_____R5$0`4(:'````#I
M`/____\E2$`%"&AX````Z?#^____)4Q`!0AH@````.G@_O___R500`4(:(@`
M``#IT/[___\E5$`%"&B0````Z<#^____)5A`!0AHF````.FP_O___R5<0`4(
M:*````#IH/[___\E8$`%"&BH````Z9#^____)61`!0AHL````.F`_O___R5H
M0`4(:+@```#I</[___\E;$`%"&C`````Z6#^____)7!`!0AHR````.E0_O__
M_R5T0`4(:-````#I0/[___\E>$`%"&C8````Z3#^____)7Q`!0AHX````.D@
M_O___R6`0`4(:.@```#I$/[___\EA$`%"&CP````Z0#^____)8A`!0AH^```
M`.GP_?___R6,0`4(:``!``#IX/W___\ED$`%"&@(`0``Z=#]____)91`!0AH
M$`$``.G`_?___R680`4(:!@!``#IL/W___\EG$`%"&@@`0``Z:#]____):!`
M!0AH*`$``.F0_?___R6D0`4(:#`!``#I@/W___\EJ$`%"&@X`0``Z7#]____
M):Q`!0AH0`$``.E@_?___R6P0`4(:$@!``#I4/W___\EM$`%"&A0`0``Z4#]
M____);A`!0AH6`$``.DP_?___R6\0`4(:&`!``#I(/W___\EP$`%"&AH`0``
MZ1#]____)<1`!0AH<`$``.D`_?___R7(0`4(:'@!``#I\/S___\ES$`%"&B`
M`0``Z>#\____)=!`!0AHB`$``.G0_/___R740`4(:)`!``#IP/S___\EV$`%
M"&B8`0``Z;#\____)=Q`!0AHH`$``.F@_/___R7@0`4(:*@!``#ID/S___\E
MY$`%"&BP`0``Z8#\____)>A`!0AHN`$``.EP_/___R7L0`4(:,`!``#I8/S_
M__\E\$`%"&C(`0``Z5#\____)?1`!0AHT`$``.E`_/___R7X0`4(:-@!``#I
M,/S___\E_$`%"&C@`0``Z2#\____)0!!!0AHZ`$``.D0_/___R4$004(:/`!
M``#I`/S___\E_#\%"&:0``````````"-3"0$@^3P_W'\58GE5E-1B<N#[#"+
M002)1=2+00B)1=!EH10```")1>0QP(U%T%"-1=104>BV_?__@\0,:("4!`AH
M@)0$"&@PE00(Z)]&``"#Q!"`/31!!0@`=3'HWOS__X7`HW!1!0@/A)$!``"#
M[`Q0Z"C\__]9_S4P004(Z`S___^#Q!#&@'D%````@^P,_S4P004(Z/3^__^`
MB`H#```"6O\U,$$%".CA_O__@(@*`P```8L#@\00@\`%/?___S\/AP4!``"#
M[`S!X`)0Z*O\__^+==2+&X/$$*-D404(QP5H404(!````(L6@_L!QT`$B]\$
M",=`#([?!`B)$(L5%$$%"(E0"+H!````?A6-M"8`````BPR6B4R0#(/"`3G:
M=?*#[`S'1)@,`````(/#`VH`4%-HL,0$"/\U<%$%".B(_?__@\0@A<")PW11
M@^P,_S5P404(Z)'[__^-5>"X3]X$".CT)@``@\00A<!T1(/L#/\U<%$%".@O
M^___Z!K]__^#Q!")V(MUY&4S-10```!U9(UE]%E;7EV-8?S#@^P,_S5P404(
MZ)#]__^#Q!")P^N:H6Q1!0B%P'0?@^P,4.BG1```@\00ZZ504&@X004(:/_=
M!`CH4?S__XU5X+@$W@0(Z'0F``"%P*-L404(#X1Z____Z\7HP/K__X/L#&H!
MZ,;[__\Q[5Z)X8/D\%!44FB0W00(:##=!`A15F@0E@0(Z.7[___T9I!FD(L<
M),-FD&:09I!FD&:09I"X&T$%""T8004(@_@&=AJX`````(7`=!%5B>6#[!1H
M&$$%"/_0@\00R?/#D(UT)@"X&$$%""T8004(P?@"B<+!ZA\!T-'X=!NZ````
M`(72=!)5B>6#[!!0:!A!!0C_TH/$$,GSPXUT)@"-O"<`````@#U+004(`'43
M58GE@^P(Z'S____&!4M!!0@!R?/#9I"XZ#X%"(L0A=)U!>N3C78`N@````"%
MTG3R58GE@^P44/_2@\00R>EU____9I!FD)!55XUH.%93@>P,`P``B40D/(V$
M)(````")?"0,98L5%````(F4)/P"```QTHGOB70D"(G%C70F`(L'BU<$,=O'
M1?P`````@\40@\<(#\B)UHG1B47HB=#!YAC!X`B)VB4``/\`"?")QHG(#ZS0
M&,'J&`G&B10DB<B)V@^LT`@E`/\```GPB47PBP0DB47TC80D``$``#GH=9^-
MA"3@````C90DX`(``(GVC;PG`````(M(!#-(W(/`"(M8^#-(I#-8T#-(E#-8
MH,=`%``````S6)")SXG>B=F)^P^DRP$!R8D,)(E<)`2)\8G[#ZS9'PL,)(E(
M$#G0=;>+1"0\BSB+:`2+<!B)^HMX"(GIBV@,B70D"(G+BW`@B4PD%(G1B7PD
M&(MX$(EL)!R+:!2)="18B=:)5"00B3PDBW@<P>8%#ZS9&XEL)`2)]3'2B7PD
M#(MX)`G-BW0D6`-T)'B)Z(E\)%R+?"1<$WPD?(GQ@<&9>8):B?N#TP`!R(M,
M)!@1VHL<)(E$)"")5"0DBU0D"(G=,=6)[R'/B?J+?"0(,?J+?"0@BT0D&(L<
M),=$)"0`````QT0D-``````!UXM4)!R)QHE\)"B)?"0@B<?!YAZ)U8GQBW0D
M"`^L[P*)S8M,)!")^(M\)`P)Q0.T)(`````3O"2$````B6PD,(GPBW0D!`69
M>8):B?J)WX/2`#'O(W0D%"'/,SPD,W0D!(GYB?,!P8M$)"`1TXM4)"2)3"1`
MB5PD1(M<)$")Q@^LT!N+5"04P>8%B<&+1"00"?$!RS'_B<&)WHE<)%`/K-`"
MP>$>"<&+1"0HB4PD0#'I(<B)PHL$)#'J`X0DB````(G1B?H%F7F"6@'!B?#!
MX`6)1"0HB?"+;"0H#ZS0&XM4)"3'1"0L`````(E$)$@+;"1(BT0D(,=$)"0`
M`````>F)3"0HB4PD8(G!P>$>#ZS0`HM4)$")S0G%BT0D4(EL)$B)TS'K(=@Q
MT(M4)"R)P8M$)#`#A"20````!9EY@EH!P8M$)"C!X`6)1"0@BT0D*(ML)"`/
MK-`;B40D,`ML)#"+1"1``>F)3"0@B4PD4(GQP>$>#ZS^`HG+BXPDF````(M\
M)$@)\XMT)&")VHE<)$"!P9EY@EH!P3'ZBT0D("'6BU0D)(GU,?V)Q@'IP>8%
M#ZS0&XE$)#"+;"0PBT0D*(M4)"S'1"0T`````,=$)"P`````"?6+="1``>F)
M3"1@B4PD,(G!P>$>B?4/K-`"BY0DH````(G+"<.+1"1(B5PD0('"F7F"6HG1
MBU0D-`'!,=V)Z(ML)%`AQ8M$)#")[S'W`?G!X`6)QXM$)#`/K-`;BU0D),=$
M)"0`````B40D*`M\)"B+1"0@`?F+?"1`B4PD*(E,)%")P0^LT`*+E"2H````
MP>$>B<T)Q8'"F7F"6HEL)$B)T8GZ`?$QZB-4)&")U3']BWPD*`'IBVPD+(GX
MP>`%B>J)1"0@B?B+;"0@#ZS0&PG%`>F)3"1@B4PD((M\)#"+;"0TBT0D0,=$
M)#0`````B?J)_HGOP>(>B=.+E"2P````#ZS^`HM\)$@)\X'"F7F"6HMT)%")
MT8G:B5PD0`'!,?J+1"0@(=:+5"0DB?4Q_8G&`>G!Y@4/K-`;BU0D+(G+QT0D
M+`````")1"0PBT0D*(ML)#")P0GUBW0D0`'KP>$>#ZS0`HN4)+@```")7"0P
MB?6)7"10B<L)PXM$)$B!PIEY@EJ)7"1`B=&+5"0T`<$QW8GHBVPD8"'%BT0D
M,(GO,?<!^<'@!8G'BT0D,`^LT!N+5"0DB40D*`M\)"B+1"0@`?F)3"1@B4PD
M*(G!#ZS0`HN4),````#!X1Z+?"1`B<W'1"0D``````G%@<*9>8):B6PD2(G1
MB?H!\3'J(U0D4(G5,?V+?"0H`>F+;"0LB?C!X`6)ZHE$)"")^(ML)"`/K-`;
MBWPD,`G%BT0D0`'IBVPD-,=$)#0`````B?J)_HE,)%#!XAZ)3"0@B>^)TXN4
M),@````/K/X"BWPD2`GS@<*9>8):BW0D8(G1B=J)7"1``<$Q^HM$)"`AUHM4
M)"2)]3']B<8!Z<'F!0^LT!N+5"0LB40D,(ML)#"+1"0H"?6+="1``>F)3"0P
MB4PD8(G!P>$>B?4/K-`"BY0DT````(G+"<.+1"1(B5PD0('"F7F"6HG1`<$Q
MW8GHBVPD4"'%BT0D,(GO,?<!^<'@!8G'BT0D,(M4)#3'1"0L``````^LT!N+
M5"0DQT0D)`````")1"0H"WPD*(M$)"`!^8M\)$")3"10B4PD*(G!#ZS0`HN4
M)-@```#!X1Z)S0G%@<*9>8):B6PD2(G1B?H!\3'J(U0D8(G5,?V+?"0H`>F+
M;"0LB?C!X`6)ZHE$)"")^(ML)"`/K-`;BWPD,`G%BT0D0`'IBVPD-(GZB?Z)
M3"0@P>(>B4PD8(GOB=.+E"3@````#ZS^`HM\)$@)\X'"F7F"6HMT)%")T8G:
MB5PD0`'!,?J+1"0@(=:+5"0DB?4Q_8G&`>G!Y@4/K-`;B<N)1"0PBVPD,`GU
M`>N)7"10B5PD,(M$)"B+5"0LBW0D0,=$)#0`````QT0D+`````")P<'A'HGU
M#ZS0`HG+BXPDZ````(M4)#0)PXM$)$B)7"1`@<&9>8):`<$QW8GHBVPD8"'%
MBT0D,(GO,?<!^<'@!8G'BT0D,`^LT!N+5"0DQT0D)`````")1"0H"WPD*(M$
M)"`!^8M\)$")3"0HB4PD8(G!P>$>B<V+C"3P````#ZS0`HGZ"<6!P9EY@EH!
M\3'J(U0D4(EL)$B)U3']BWPD*`'IBVPD+(GXP>`%B>J)1"0@B?B+;"0@#ZS0
M&XM\)#`)Q0'IBVPD-(GZB?Z)3"10P>(>B4PD((GOB=.+E"3X````#ZS^`HM$
M)$"+?"1("?.!PIEY@EJ+="1@B=&)VHE<)$`!P3'ZBT0D("'6BU0D),=$)#0`
M````B?4Q_8G&`>G!Y@4/K-`;BU0D+,=$)"P`````B40D,(ML)#"+1"0H"?6+
M="1``>F)3"0PB4PD8(G!P>$>B?4/K-`"BY0D``$``(G+"<.+1"1(B5PD0('"
MF7F"6HG1BU0D-`'!,=V)Z(ML)%`AQ8M$)#")[S'W`?G!X`6)QXM$)#`/K-`;
MBU0D)(E$)"@+?"0HBT0D(`'YBWPD0(E,)%")3"0HB<$/K-`"BY0D"`$``,'A
M'HG-"<6!PIEY@EJ);"1(B=&)^@'Q,>HC5"1@B=4Q_8M\)"C'1"0D``````'I
MBVPD+(GXP>`%B>J)1"0@B?B+;"0@#ZS0&XM\)#`)Q8M$)$`!Z8ML)#3'1"0T
M`````(GZB?Z)3"1@P>(>B4PD((GOB=.+E"00`0``#ZS^`HML)$B+?"1@"?.!
MPIEY@EJ)T8M4)$B)7"1``<&+1"10,=HAT(M4)"0QQ8M$)"`!Z8G+B<8/K-`;
MBU0D+,'F!8E$)#"+1"0HBVPD,(G!"?4!Z\'A'HML)$`/K-`"B5PD,(E<)%")
MRXN4)!@!```)PXM$)$B)WH'"H>O9;@'0,=V+5"0T,>^)\XGY`<&+1"0PP>`%
MB<>+1"0P#ZS0&XE$)"B+;"0HBT0D((M4)"3'1"0L`````(ET)$@)_<=$)"0`
M`````>F)3"1@B4PD*(G!P>$>BWPD*`^LT`*)S8N4)"`!```)Q8M$)$");"1`
M@<*AZ]EN`=`QZXML)%`QW8GIBVPD+`'!B?C!X`6)1"0@B>J)^(ML)""+?"0P
M#ZS0&PG%B?J)_@'IBVPD-,'B'HM$)$B)3"0@B4PD4(GOB=6+E"0H`0``#ZS^
M`HM\)&`)]8'"H>O9;@'0B6PD2#-L)$"+5"0D,>^)^0'!BT0D((G&#ZS0&\'F
M!8M4)"R)1"0PBVPD,(M$)"@)]0'I,?^)SHE,)&")P<'A'@^LT`*)RPG#B5PD
M,(N4)#`!``"+C"0T`0``BT0D0(ML)$B!PJ'KV6Z#T0")RXG1,=(!R!':,VPD
M,(E$)"B)5"0LBU0D4(GPBUPD,,=$)"P`````,>J)T0-,)"C!X`6)1"0HB?J)
M\`^LT!N+;"0HBU0D)(E$)$`+;"1`BT0D(`'IB4PD*(E,)%")P<'A'@^LT`*)
MS8N4)#@!```)Q8M$)$B);"1`@<*AZ]EN`=`QZXML)&"+5"0L,=V)Z0'!BT0D
M*,'@!8E$)""+1"0HBVPD(`^LT!N)\HE$)$@+;"1(`>G!XAZ)3"1@B=6)3"0@
MBY0D0`$``(M$)#`/K/X"BWPD4,=$)"0`````"?6!PJ'KV6['1"0T``````'0
MB6PD2#-L)$"+5"0D,>^)^8M\)&`!P8M$)"")RXG&#ZS0&XM4)"S!Y@7'1"0L
M`````(E$)#"+1"0HBVPD,(G!"?4!Z\'A'HML)$@/K-`"B5PD,(E<)%")RXN4
M)$@!```)PXM$)$")WH'"H>O9;@'0,=V+5"0T,>^)\XGY`<&+1"0PP>`%B<>+
M1"0P#ZS0&XM4)"2)1"0H"WPD*(M$)"`!^8E,)&")3"0HB<'!X1X/K-`"B<V+
ME"10`0``"<6+1"1(B70D2(EL)$"+?"0H@<*AZ]ENQT0D)``````!T#'KBVPD
M4#'=B>F+;"0L`<&)^,'@!8E$)"")ZHGXBVPD((M\)#`/K-`;"<6)^HG^`>F+
M;"0TP>(>BT0D2(E,)%")3"0@B>^)U8N4)%@!```/K/X"BWPD8`GU@<*AZ]EN
M`=");"1(,VPD0(M4)"0Q[XGY`<&+1"0@B<8/K-`;P>8%BU0D+(E$)#"+;"0P
MBT0D*`GU`>DQ_XML)$B)SHE,)&")P<'A'@^LT`*+E"1@`0``B<N+C"1D`0``
M"<.+1"1`B5PD,('"H>O9;H/1`(G+B=$QT@'($=HS;"0PB40D*(E4)"R+5"10
MB?`QZHG1`TPD*,'@!8E$)"B)^HGP#ZS0&XML)"B+5"0DB40D0`ML)$"+1"0@
MBUPD,,=$)"P`````QT0D)``````!Z8E,)"B)3"10B<'!X1X/K-`"B<V+E"1H
M`0``"<6+1"1(B6PD0('"H>O9;@'0,>N+;"1@BU0D+#'=B>D!P8M$)"C!X`6)
M1"0@BT0D*(ML)"`/K-`;B?*)1"1("VPD2(M$)#`!Z<'B'HG5BY0D<`$``(E,
M)"`/K/X"BWPD4(E,)&`)]8'"H>O9;@'0B6PD2#-L)$"+5"0D,>^)^0'!BT0D
M((G+B<8/K-`;P>8%B40D,(M$)"B+;"0PBU0D+(M\)&#'1"0T`````(G!QT0D
M+``````)]0'KP>$>BVPD2`^LT`*)7"10B5PD,(G+BY0D>`$```G#BT0D0(G>
M@<*AZ]EN`=`QW8M4)#0Q[XGSB?D!P8M$)##!X`6)QXM$)#`/K-`;BU0D),=$
M)"0`````B40D*`M\)"B+1"0@`?F)3"0HB4PD8(G!P>$>BWPD*`^LT`*)S8N4
M)(`!```)Q8M$)$B)="1(B6PD0('"H>O9;@'0,>N+;"10,=V)Z8ML)"P!P8GX
MP>`%B40D((GJB?B+;"0@#ZS0&PG%`>F)3"10B4PD((M\)#"+;"0TBT0D2(GZ
MB?Z)[\'B'HG5BY0DB`$```^L_@*+?"1@"?6!PJ'KV6X!T(EL)$@S;"1`BU0D
M)#'OB?D!P8M$)"")Q@^LT!O!Y@6+5"0LB40D,(ML)#"+1"0H"?4!Z3'_BVPD
M2(G.B4PD8(G!P>$>#ZS0`HN4))`!``")RXN,))0!```)PXM$)$")7"0P@<*A
MZ]EN@]$`B<N)T3'2`<@1VC-L)#")1"0HB50D+(M4)%")\,=$)"P`````,>J)
MT0-,)"C!X`6)1"0HB?J)\`^LT!N+;"0HB40D0`ML)$`!Z8E,)%")3"0HBT0D
M((M4)"2+7"0PQT0D)`````#'1"0T`````(G!P>$>#ZS0`HG-BY0DF`$```G%
MBT0D2(EL)$"!PJ'KV6X!T#'KBVPD8(M4)"PQW8GI`<&+1"0HP>`%B40D((M$
M)"B+;"0@#ZS0&XGRB40D2`ML)$B+1"0P`>G!XAZ)U8N4)*`!``")3"0@#ZS^
M`HM\)%")3"1@"?6!PJ'KV6X!T(EL)$@S;"1`BU0D)#'OB?D!P8M$)"")RXG&
M#ZS0&XM4)"S!Y@6)1"0PBT0D*(ML)#")P0GU`>O!X1X/K-`"B5PD4(E<)#")
MRXN4)*@!```)PXM$)$"+;"1(BWPD8(G>QT0D+`````")="1@@<*AZ]EN`=`Q
MW8M4)#0Q[XGY`<&+1"0PP>`%B<>+1"0P#ZS0&XM4)"3'1"0D`````(E$)"@+
M?"0HBT0D(`'YBWPD4(E,)$")3"0HB<'!X1X/K-`"B<V+E"2P`0``B?$)Q8M$
M)$B)[H'"H>O9;HGSB70D:`'0,>F+;"0L,<^)^8M\)"@!P8GJB?C!X`6)1"0@
MB?B+;"0@#ZS0&XM4)#2)1"1("VPD2(M$)#`!Z8G'B=4/K.\"B4PD2(E,)"")
MP<'A'HGXB?*)S3'_"<6+1"1`">LAZHEL)$`AV(G!"=&)SHN,)+@!``"+G"2\
M`0``BT0D8('!W+P;CX/3`#'2`<B)\1':B?L!P8M$)""+?"0L$=.+5"0DB4PD
M,(E<)#3'1"0T`````(G&QT0D+``````/K-`;P>8%B<$)\8MT)"B)R(M,)#`!
MP8E,)%")3"0PB?$/K/X"P>$>B?")SXMT)$`)QXM$)$B)^XGZB7PD2`GS(?*+
M?"0D(=B)P8M$)&@)T8N4),`!``")SHGS@<+<O!N/`="+5"0T`<.+1"0PB<8/
MK-`;P>8%B40D*(ML)"B+1"10"?6+="0@`>N)7"0HB5PD8(GQP>$>#ZS^`HM\
M)$B)RPGSB=J)^XGYB50D4`G3(=$AV(G%BT0D0`G-BXPDR`$``('!W+P;CP'(
MB>D!P8M$)"B+5"0LBWPD-,=$)"0`````QT0D-`````")Q@^LT!O!Y@6+5"10
M"<:+1"1@`?&+="0PB4PD:(E,)"")TXGQP>$>#ZS^`HG-BWPD+,=$)"P`````
M"?4)ZR'JB6PD0"'8B<&+1"1("=&+E"30`0``B<Z)\X'"W+P;CP'0BU0D)`'#
MBT0D((G&#ZS0&\'F!8E$)#"+;"0P"?6+="0H`>N)7"0PB5PD8(GQBUPD0`^L
M_@+!X1Z)\(G/BXPDV`$```G'BT0D:(GZB7PD2`G:(=")^HG%BT0D4"':"=6!
MP=R\&X^+5"0T`<B)Z0'!BT0D,(G&#ZS0&\'F!8E$)"B+;"0H"?4!Z8E,)&B)
M3"0HBW0D((M\)"2+1"1@QT0D)`````")\<'A'@^L_@*+?"1(B<N+C"3@`0``
M"?.)VHG[B50D4`G3(=B)^XM\)#2)Q8M$)$`ATPG=@<'<O!N/BU0D+(GK`<@!
MPXM$)"B)Q@^LT!O!Y@6+5"10"<:+1"1H`?.+="0PB5PD8(E<)""+G"3L`0``
MB?'!X1X/K/X"B<V)T3'_"?4)Z2'JB6PD0"'(B<&+1"1("=&)SHN,).@!``"!
MP=R\&X^#TP`QT@'(B?$1VHG[`<&+1"0@BWPD+!'3BU0D)(E,)#")7"0TBUPD
M0(G&QT0D-``````/K-`;P>8%B<$)\8MT)"B)R(M,)#`!P8E,)&B)3"0PB?$/
MK/X"P>$>B?")SPG'BT0D8(GZB7PD2,=$)"P`````"=HAT(GZBWPD)"':B<&+
M1"10"=&+E"3P`0``QT0D)`````")SHGS@<+<O!N/`="+5"0T`<.+1"0PB<8/
MK-`;P>8%B40D*(ML)"B+1"1H"?6+="0@`>N)7"1@B5PD*(GQP>$>#ZS^`HM\
M)$B)RPGSB=J)^XGYB50D4`G3(=&+5"0L(=B+?"0TB<6+1"1`"<V+C"3X`0``
M@<'<O!N/`<B)Z0'!BT0D*(G&#ZS0&\'F!8M4)%`)QHM$)&`!\8MT)#")3"0@
MB4PD:(G3B?'!X1X/K/X"B<T)]0GK(>J);"1`(=B)P8M$)$@)T8N4)``"``")
MSHGS@<+<O!N/`="+5"0D`<.+1"0@B<8/K-`;P>8%B40D,(ML)#`)]0'KB5PD
M8(MT)"B+?"0LB5PD,(M<)$#'1"0T`````(GQQT0D+``````/K/X"P>$>B?")
MSXN,)`@"```)QXM$)&B)^HE\)$@)VB'0B?J+?"0DB<6+1"10(=H)U8'!W+P;
MCXM4)#3'1"0D``````'(B>D!P8M$)#")Q@^LT!O!Y@6)1"0HBVPD*(M$)&`)
M]8MT)"`!Z8E,)&B)3"0HB?'!X1X/K/X"BWPD2(G+BXPD$`(```GSB=J)^XE4
M)%`)TR'8B?N+?"0TB<6+1"1`(=,)W8'!W+P;CXM4)"P!R(GI`<&+1"0HB<N)
MQ@^LT!O!Y@6+5"10"<:+1"1H`?.+="0PB5PD8(E<)"")\<'A'@^L_@*)S8G1
M,?\)]0GI(>J);"1`(<B+G"0<`@``B<&+1"1("=&)SHN,)!@"``"!P=R\&X^#
MTP`QT@'(B?$1VHG[`<&+1"0@BWPD+!'3BU0D)(E,)#")7"0TBUPD0(G&QT0D
M-`````#'1"0L``````^LT!O!Y@6)P0GQBW0D*(G(BTPD,`'!B4PD:(E,)#")
M\0^L_@+!X1Z)\(G/"<>+1"1@B?J)?"1("=HAT(GZBWPD)"':B<&+1"10"=&+
ME"0@`@``B<Z)\X'"W+P;CP'0BU0D-`'#BT0D,(G&#ZS0&\'F!8E$)"B+;"0H
MBT0D:`GUBW0D(`'KB5PD8(E<)"B)\<'A'@^L_@*+?"1(B<L)\XG:B?N)^8E4
M)%`)TR'1(=B)Q8M$)$`)S8N,)"@"``"!P=R\&X\!R(GI`<&+1"0HBU0D+(M\
M)#3'1"0D`````,=$)#0`````B<8/K-`;P>8%BU0D4`G&BT0D8`'QBW0D,(E,
M)&B)3"0@B=.)\<'A'@^L_@*)S8M\)"P)]0GK(>J);"1`(=B)P8M$)$@)T8N4
M)#`"``")SHGS@<+<O!N/`="+5"0D`<.+1"0@B<8/K-`;P>8%B40D,(ML)#`)
M]8MT)"@!ZXE<)#")7"1@B?&+7"1`#ZS^`L'A'HGPB<^+C"0X`@``"<>+1"1H
MB?J)?"1("=HAT(GZB<6+1"10(=H)U8'!W+P;CXM4)#0!R(GI`<&+1"0PB<8/
MK-`;P>8%B40D*(ML)"@)]0'IB4PD:(E,)"C'1"0L`````(MT)""+?"0DBT0D
M8,=$)"0`````B?'!X1X/K/X"BWPD2(G+BXPD0`(```GSB=J)^XE4)%`)TR'8
MB?N+?"0TB<6+1"1`(=,)W8'!W+P;CXM4)"P!R(GI`<&+1"0HB<N)Q@^LT!O!
MY@6+5"10"<:+1"1H`?.+="0PB5PD8(E<)""+G"1,`@``B?'!X1X/K/X"B<V)
MT3'_"?4)Z2'JB6PD0"'(B<&+1"1("=&)SHN,)$@"``"!P=R\&X^#TP`QT@'(
MB?$1VHG[`<&+1"0@BWPD+!'3BU0D)(E,)#")7"0TQT0D-`````")Q@^LT!O!
MY@6)P0GQBW0D*(G(BTPD,`'!BT0D8(E,)&B)3"0PB?'!X1X/K/X"B<L)\XMT
M)$")WXG:B5PD2(M<)$C'1"0L``````GW(?(A^(M\)"2)P8M$)%`)T8N4)%`"
M``")SHGQ@<+<O!N/`="+5"0T`<&+1"0PB<8/K-`;P>8%BY0D6`(``(E$)"B+
M;"0H"?6+="0@`>F+;"1HB4PD4(E,)"B)\0^L_@+!X1Z)\(G/"<>+1"1`@<+6
MP6+*B7PD0`'0,?N+5"0L,=V)Z0'!BT0D*(G&#ZS0&\'F!8M4)#0)QHM$)#`!
M\3'_B<Z)3"1@B<'!X1X/K-`"B<V+E"1@`@``"<6+1"1(B6PD,(ML)$"!PM;!
M8LH!T#-L)#")^C-L)%")Z0'!B?#!X`6)1"0@B?"+;"0@#ZS0&XE$)$@+;"1(
M`>F)3"10B4PD((M$)"B+5"0LQT0D)`````#'1"0L`````(G!P>$>#ZS0`HG+
MBY0D:`(```G#BT0D0(G=B5PD0(M<)#"!PM;!8LH!T(M4)"0QZXML)&`QW8N<
M)'`"``")Z0'!BT0D(,'@!8E$)"B+1"0@BVPD*`^LT!N)\HE$)$@+;"1(BT0D
M,`'IP>(>#ZS^`HG5B4PD*(E,)&`)]8'#UL%BRHM4)"R)[XML)$`!V(E\)$@Q
M_8GNBVPD4#'UB>D!P8M$)"B)RXG&#ZS0&\'F!8M4)"0)QHM$)"`!\S'_B5PD
M4(G>B<'!X1X/K-`"B<V+E"1X`@``"<6+1"1`B6PD,(ML)$B!PM;!8LH!T#-L
M)#")^C-L)&#'1"0D`````(GI`<&)\,'@!8E$)"")\(ML)"`/K-`;BU0D+,=$
M)"P`````B40D0`ML)$"+1"0H`>F)3"0@B4PD8(G!P>$>#ZS0`HG+BY0D@`(`
M``G#BT0D2(G=B5PD0(M<)#"!PM;!8LH!T(M4)"0QZXML)%`QW8N<)(@"``")
MZ0'!BT0D(,'@!8E$)"B+1"0@BVPD*`^LT!N)\HE$)$@+;"1(BT0D,`'IP>(>
M#ZS^`HG5B4PD*(E,)$@)]8'#UL%BRHGOBVPD0`'8B7PD,#']B>Z+;"1@,?6)
MZ0'!BT0D*(M4)"R+7"0PB<8/K-`;P>8%BU0D),=$)"0`````"<:+1"0@`?$Q
M_XG.B4PD4(G!P>$>#ZS0`HG-BY0DD`(```G%BT0D0(EL)$"!PM;!8LH!T#'K
MBVPD2(GZ,=V)Z0'!B?#!X`6)1"0@B?"+;"0@#ZS0&XM4)"R)1"1("VPD2(M$
M)"@!Z8E,)"")3"1@B<'!X1X/K-`"B<V+E"28`@``"<6+1"0PB6PD2('"UL%B
MR@'0,VPD0(M4)"0S;"10B>D!P8M$)"#!X`6)1"0HBT0D((ML)"@/K-`;B?*)
M1"0P"VPD,`'IB?V)]P^L[P+!XAZ)3"10B4PD*(GXQT0D+`````")UXN<)*`"
M```)QXML)$B+1"1`BU0D+(E\)$"!P];!8LH!V#']B>Z+;"1@,?6)Z0'!BT0D
M*(G+B<8/K-`;P>8%BU0D),=$)"0`````"<:+1"0@`?,Q_XG>B5PD8(G!P>$>
M#ZS0`HG-BY0DJ`(```G%BT0D2(EL)#"+;"1`@<+6P6+*`=`S;"0PB?HS;"10
MB>D!P8GPP>`%B40D((GPBVPD(`^LT!N+5"0LB40D2`ML)$B+1"0H`>F)3"0@
MB4PD4(G!P>$>#ZS0`HG+BY0DL`(```G#BT0D0(G=B5PD0(M<)#"!PM;!8LH!
MT#'KBVPD8#'=B>D!P8M$)"#!X`6)1"0HBT0D((M4)"2+;"0HBYPDN`(``,=$
M)"P`````#ZS0&XGRB40D2`ML)$B+1"0P`>G!XAX/K/X"B=6)3"1@B4PD*`GU
M@</6P6+*BU0D+(GOBVPD0`'8B7PD2#']B>Z+;"10,?6)Z0'!BT0D*(G&#ZS0
M&\'F!8M4)"0)QHM$)"`!\3'_B<Z)3"10B<'!X1X/K-`"BY0DP`(``(G-BXPD
MQ`(```G%BT0D0(EL)#"+;"1(@<+6P6+*@]$`B<N)T3'2`<@1VC-L)#`QVS-L
M)&")Z0'!B?`1T\'@!8GZB40D((GPBVPD(`^LT!LQTHE$)$`+;"1``>D1TXG*
MB50D0(E<)$2)5"0@QT0D)`````"+1"0HBU0D+,=$)"P`````B<'!X1X/K-`"
MBY0DR`(``(G+BXPDS`(```G#BT0D2(G=@<+6P6+*B6PD2(/1`(G+B=$QT@'(
M$=J+7"0P,>N+;"10,=TQVXGI`<&+1"0@$=.+5"0DP>`%B40D*(M$)""+;"0H
M#ZS0&S'2B40D4`ML)%"+1"0P`>D1TXGRB4PD*`^L_@+!XAZ)7"1DBYPDT`(`
M`(G5B4PD8`GUB[0DU`(``('#UL%BRHGOBVPD2(G9B7PD4(/6`#'2`<@1\C']
M,=N)[HML)$`Q]8GI`<&+1"0H$=.+5"0LB<8/K-`;P>8%,=()QHGPB=Z)RP'#
MBT0D(!'6BU0D)(E<)&B)="1L,?^)WHG!P>$>#ZS0`HG-"<6);"1`BY0DV`(`
M`(M$)$B+;"10QT0D-`````#'1"0D`````('"UL%BR@'0,VPD0(GZ,VPD8(GI
M`<&)\,'@!8E$)"")\(ML)"`/K-`;BU0D+(E$)#`+;"0PBT0D*`'IB4PD,(E,
M)$B)P<'A'@^LT`*+E"3@`@``B<N+C"3D`@``"<.+1"10B=V!PM;!8LJ);"0H
M@]$`B<N)T3'2`<@1VHM<)$`QZXML)&@QW3';B>D!P8M$)#`1TXM4)#3!X`6)
M1"0@BT0D,(ML)"`/K-`;,=*)1"10"VPD4`'I$=.)RHE4)%")5"0@B?(/K/X"
MP>(>B5PD5(N<).@"``")\(G7"<>+1"1`BVPD*('#UL%BRHM4)"2)?"1``=@Q
M_8GNBVPD2#'UB>D!P8M$)"")Q@^LT!O!Y@6+5"0T"<:)\`'(,?^)QHM$)#")
MP<'A'@^LT`*)S8M4)""+3"0D"<6+1"0HB6PD8`^DT1[!XAZ)5"0PB4PD-(M4
M)""+3"0D#ZS*`L'I`HE,)"2+C"3P`@``B50D((GZ@<'6P6+*`<B+3"1`,>F+
M;"10,<V)Z0'!B?`/I,(%P>`%B40D*(E4)"R)\(GZBVPD*`^LT!O!ZAN)1"1(
M"VPD2(E4)$R)Z`'(B<$#3"00BT0D/(G#QT`$`````(D(BT0D&(ML)##'0PP`
M````QT,4`````,=#'``````!\`ML)"#'0R0`````B4,(B>@#!"2)0Q"+1"1@
M`T0D"(E#&(M$)$`#1"18B4,@BX0D_`(``&4S!10```!U"X'$#`,``%M>7UW#
MZ&34__^-="8`A<`/A)L```!55U93@^P<BPT@004(A<F)3"0(=%4/M@B$R71<
M@/D]=%>)PX/#`0^V"X3)=`6`^3UU\2G#BTPD"(LIA>UT+(E4)`R)QHG/9I"#
M[`135E7HM=;__X/$$(7`=0>`?!T`/70?@\<$BR^%[77>@\0<,<!;7E]=PXUT
M)@`QV^NXC70F`(GZ*U0D"(M$)`S!^@*)$(/$'(U$'0%;7E]=PS'`PXUV`(V\
M)P````!3B<.#[!AEH10```")1"0,,<"-5"0(B=CH,____X7`=#J-M"8`````
MBU0D"*$@004(C020BU`$A=*)$'35C78`@\`$BU`$A=*)$'7TC50D"(G8Z/G^
M__^%P'7-BT0D#&4S!10```!U!8/$&%O#Z#[3__^-M"8`````C;PG`````%57
MB<=64XG3@^PX9:$4````B40D*#'`,<"`.CT/E,`!PU/H2=3__X/$$(G%B?B-
M5"08Z)G^__^%P`^$`0$``(/L#(G&4.@FU/__@\00.<4/AM,```"+1"08C0R%
M``````^V!X3`#X2+`0``/#T/A(,!``")^.L.B?:-O"<`````@/H]=`J#P`$/
MMA"$TG7Q*?B-1"@"@^P,BS4@004(4`'.Z&K3__^#Q!"%P(D&#X16`0``H2!!
M!0B+5"08C4\!BQ20#[8'/#V(`G0AA,!U#>L;C;0F`````#P]=!"#P0$/MD'_
M@\(!A,"(`G7LQ@(],<"-M"8`````#[8,`XA,`@&#P`&$R77Q,<"+?"0<93,]
M%`````^%^0```(/$+%M>7UW#C;8`````@\,!#[9#_X/&`83`B$;_=>_KS)"-
M="8`BQ4@004(BS*%]@^$K0```#'`ZP:-="8`B?"-<`&+#+*%R77TC02%#```
M`(L-8%$%"(7)=#.#[`A04NB!TO__@\00A<"C($$%"'1^C0RU`````,=$L`0`
M````B70D&.F]_O__D(UT)@")5"0(@^P,QP5@404(`0```%#H4=+__X/$$(7`
M=$.-#+4`````@^P$48M4)!")3"044HE$)!10Z,S0__^+1"08@\00BTPD#*,@
M004(ZYPQP.F4_O__N`@````Q]NEB____N/_____I]O[__^@8T?__D(VT)@``
M``!55U93B<:![(P```!EH10```")1"1\,<"%]G0%@#X`=1^+1"1\93,%%```
M``^%'P$``('$C````%M>7UW#C78`@^P,5NC7T___@\00A<")QW3/C;8`````
M@^P,5^@_T___@\00A<")PP^$N@```(![$RX/A(@```"#[`R-:Q-6Z,S1__^)
M+"2)1"0<Z,#1__^+3"0<C40!`HD$).A0T?__B<-86E56:+#=!`AJ_VH!4^A[
MT___@\0<C40D(%!3:@/H"]/__X/$$(/X_W00BT0D+"4`\```/0!```!T:X/L
M#%/H2M#__X/$$(/L#%/HKL___X/$$.E>____C;8`````#[9#%(3`#X1,____
M/"X/A63___^`>Q4`#X0Z____Z57___^0C70F`(/L#%?HW]+__XDT).BGS___
M@\00Z>#^__^-M"8`````B=CHL?[__^N8Z+K/__^-=@"-O"<`````4XG#@^P4
M_S4P004(Z&_2__^#Q`P%.`$``%!3:@/H;M+__X/$$(7`=`>#Q`@QP%O#@^P,
M_S4P004(Z$+2__^+@$@!``"#Q!`E`/```#T`0```=".#[`S_-3!!!0CH']+_
M_XN`2`$``(/$$"4`\```/0"@``!ULX/L"&H"4^A?T?__@\00A<`/E,"#Q`@/
MML!;P^L-D)"0D)"0D)"0D)"0D%57B<=64XG5@>P@$```9:$4````B80D$!``
M`#'`:/\/``"-="045FBVW00(Z"_/__^#Q!"%P'Y@C5C_@'P<#`!T3HG#@^P$
M4VHO5NB0T/__@\00A<!T08/L#/\U,$$%".A[T?__4U974.@2T?__@\0@BX0D
M#!```&4S!10```!U-8'$'!```%M>7UW#C70F`(7;=;"-="8`@^P,_S4P004(
MZ#K1__^#Q`Q55U#HO\[__X/$$.N[Z%7.__^0C70F`(/L&/\U,$$%".@2T?__
M:+C?!`AHD)($"&C%W00(4.BMS___@\0LPXGVC;PG`````(/L&/\U,$$%".CB
MT/__B00DZ+K___]8_S4P004(Z,[0__]:66H`:(7?!`AHA=\$"&BPV`0(:.'=
M!`A0Z`#0__^#Q"S#C;8`````C;\`````5U93@>P0(```9:$4````B80D#"``
M`#'`Z&/.__^#[`AHP=T$"%!H]MT$"&@!$```:@&-7"0F4^BTT/__@\0@A<!X
M98/L!&@`$```C;PD$Q```%=3Z,?-__^#Q!"%P(G&>$:-0`&#[`Q0Z$+.__^#
MQ!"%P(G#=#&#[`165U#H[LS__\8$,P"#Q!")V(N4)`P@``!E,Q44````=1&!
MQ!`@``!;7E_#C78`,<#KW^@?S?__ZPV0D)"0D)"0D)"0D)"0Z3O___^-="8`
MC;PG`````%575E.!["P0``"+G"1`$```C50D&(N\)$00``!EH10```")A"0<
M$```,<"X!-X$".AK^/__@^P(B<9J+U/HWLW__X/$$(7`="V)VK@-W@0(Z'OY
M__^)V(N4)!P0``!E,Q44````#X5(`0``@<0L$```6UY?7<.#[`Q3Z,'-__]:
M68E$)!1H&MX$"%?HL,[__X/$$(G%BT0D#(U\)!R#P`&)1"0,C70F`(7M=)V`
M?0``=06]`MX$"(7V=!6#[`A55NB+R___@\00A<`/A)L```"#[`Q5Z&?-__^#
MQ!"`?`7_+W44D(UT)@"#Z`&`?`7_+\9$!0``=/$#1"0,/?\/```/CT/___^#
M[`13:!S>!`A5:$#?!`AH`!```&H!5^C^SO__@\04_S4P004(Z*#.__^#Q`P%
M.`$``%!7:@/H?\[__X/$$(7`=2.#[`S_-3!!!0CH>L[__XN`2`$``(/$$"4`
M\```/0"```!T&8/L"&@:W@0(:@#HQLW__X/$$(G%Z23___^#[`AJ`5?HH<W_
M_X/$$(7`==6)^K@-W@0(Z"[X__^#[`Q7Z/7,__^#Q!#II/[__^A(R___D(VT
M)@````"+1"0$#[8(A,ET((U0`>L*#[8*@\(!A,ET$8#Y+W7Q#[8*B="#P@&$
MR77O\\.-=@!3@^P8BUPD((7;=$0/MA.$TG0]B%0D#X/L#%/H,,S__XU$`_^#
MQ!`/ME0D#SG#<@_K2HVV`````(/H`3G#=$&`."]T].LOC78`C;PG`````(/L
M#&H"Z);+__^#Q!"%P'1_NBX```!FB1"#Q!A;PV:0@#@O=#"#Z`$YPW+T.<-U
M)8#Z+W3+QT0D(!S>!`B#Q!A;Z1K,__^-=@"-O"<`````@#@O=0>#Z`$YPW+T
M*=B-4`*!^@`0``!W)X/``6@`$```4%-H8$$%".A#S/__@\00N&!!!0B#Q!A;
MPXVV`````(/$&#'`6\.)]HV\)P````!75H/L-&6A%````(E$)"PQP*&4WP0(
MB40D"J&8WP0(B40D#J&<WP0(B40D$J&@WP0(B40D%J&DWP0(B40D&J&HWP0(
MB40D'J&LWP0(B40D(J&PWP0(B40D)@^W!;3?!`AFB40D*K@>W@0(Z`'V__^X
M)]X$".CW]?__N"_>!`CH[?7__[@XW@0(Z./U__^X/]X$".C9]?__N$_>!`CH
MS_7__[@$W@0(Z,7U__^X6]X$".B[]?__N&7>!`CHL?7__[AOW@0(Z*?U__^X
M#=X$".B=]?__N'G>!`CHD_7__[B"W@0(Z(GU__^-5"0$N(W>!`CHR_3__X7`
M=`R)PKAEW@0(Z.OU__^-5"0$N)[>!`CHK?3__X7`=`R)PKBPW@0(Z,WU__^-
M5"0$N+O>!`CHC_3__X7`=#.)PK@$W@0(Z*_U__^ZY]X$"+@_W@0(Z*#U__^+
M1"0L93,%%````'55@\0T7E_#D(UT)@"-5"0$N,O>!`CH2O3__X7`=!:)PKA;
MW@0(Z&KU___KN9"-M"8`````C70D&[_<W@0(N0H```#SIG6?C50D);A;W@0(
MZ$#U___KC^AIR/__B?:-O"<`````@^P<9:$4````B40D##'`H1!!!0B#^/]T
M%XM,)`QE,PT4````=3Z#Q!S#C;8`````C50D"+A;W@0(Z,+S__^%P'0>#[80
M@/HP#Y7`A-(/E<(/MM(AT*,0004(Z[V-="8`,<#K\>CWQ___C;0F`````(/L
M#.CXQ___@^P,4.A/Q___@\00A<!T"(L`@\0,PV:0,<#K]HVV`````(V_````
M`%57O_/>!`A64[OIW@0(@^Q,BVPD8,=$)"#SW@0(C70D*&6A%````(E$)#PQ
MP,=$)"3IW@0(QT0D*/;>!`C'1"0L[-X$",=$)##QW@0(QT0D-`/?!`C'1"0X
M`````.LCD(/L"%50B40D&.B2QO__@\00A<!T2X7;="J+!HG?@\8$B<.-5"0<
MB?CHT_+__X7`=`6`.`!URHGJB?CH\?/__X7;==:+1"0\93,%%````'5Q@\1,
M6UY?7<.0C;0F`````(/L#%7H-\C__XM,)!B)1"0<B0PDB4PD&.@CR/__BU0D
M'(U$`@*)!"3HL\?__X/$#(M,)`Q1:!K>!`A5:$#?!`AJ_VH!4(E$)"CHTLG_
M_X/$((M4)`B)^.AT\___Z53____HFL;__XUV`(V\)P````!55U93@>PL@0``
MBX0D0($``(U4)"S'1"0P&M\$",=$)#0"W@0(QT0D.`````#'1"1(L-X$",=$
M)$RIW@0(B40D$,=$)%`?WP0(9:$4````B80D'($``#'`N`3>!`C'1"14QMX$
M",=$)%@GWP0(QT0D7`````#'1"0\#M\$",=$)$`KWP0(QT0D1`````#HGO'_
M_X7`=`F`.``/A?$#``#H_/W__X7`B<,/A`,$``"#[`Q3Z!G'__^-1``!@\00
M@^P,4.BIQO__@\00@#L`B<:)QW0ID(UT)@`/M@.#[`R#PP%0:#3?!`AJ_VH!
M5X/'`NB\R/__@\0@@#L`==R-?"1,N+#>!`CK$XGVC;PG`````(/'!(M'_(7`
M=#:-5"0LZ`WQ__^%P(G#=.>`.`!TXNBM]?__A<!TV8/L#%/H\,;__X/$$(7`
MB<5U68VT)@````"+7"0PA=MT2(`[`+\!````=1;K/(UT)@"+7+PPA=MT,(/'
M`8`[`'0HB=CH8?7__X7`=.6#[`Q3Z*3&__^#Q!"%P'35B<7K"XGVC;PG````
M`#'M@^P,B?-5Z"/&__^#Q!"+$X/#!(V*__[^_O?2(=&!X8"`@(!TZ??!@(``
M`'4&P>D0@\,"B<H`RH/;`X/L#"GSC9P#!`0``%/H@L7__XE$)!Q6B<9H.=\$
M"&@<W@0(56@^WP0(:O]J`5#HH<?__X/$*&C``0``5N@#QO__@\00@_C_='.#
M[`S_-3!!!0CH+<?__X/$#`4X`0``4/]T)!1J`^@IQ___@\00A<!T<H/L#/]T
M)!B+1"0@_S!H`.`$"&H!_S4H004(Z,/&__^#Q"`QP(N,)!R!``!E,PT4````
M#X76"0``@<0L@0``6UY?7<.-M"8`````Z+/%__^+`(/X$72!@^P(4/]T)!B+
M1"0@_S!HQ-\$".NGC;0F`````(/L#/\U,$$%".B2QO__BX!(`0``@\00)0#P
M```]`$````^%9____X/L#/\U,$$%".AKQO__B[!0`0``Z*##__^#Q!`YQ@^%
M0____X/L#/\U,$$%".A'QO__BX!(`0``@\00)?\!```]P`$```^%'/___X/L
M#%/H-<3__XU4)#R)Q;CLW@0(Z.7N__^#Q!"%P`^$L@$``(/L#%#HT<3__UM>
M4(M$)!S_,.@C]O__@\00A<")PP^$C@$``(/L#%/H3<3__X/$$(/X`WXMC70#
M_+]'WP0(N04```#SIG4;@_@$#X1-!P``@'P#^R\/A$('``"-M"8`````Z'/Z
M__^%P'4:@^P(:@!3Z"3$__^)1"0H@\00A<`/A3@!``"ZY]X$"+A;W@0(,=OH
M=.___^A/P___:(7?!`A0:!S>!`B+="085FA@WP0(:O]J`57HH,7__X/$(.LW
MC78`Z#/$__^#.!%U0.@9P___@\,!@^P,:(7?!`A34&@<W@0(5FANWP0(:O]J
M`57H9\7__X/$,(/L"&C``0``5>C&P___@\00@_C_=+:#[`S_="08Z++!__^)
MZK@$W@0(Z.;N__^)+"3H3OK__X/$$(GHZ>;]__^-="8`@^P,4(E$)!SH,_K_
M_XM$)!R)!"3HA\/__X/$$.G!_?__O@$```"X#M\$".L.C78`BT2T/(/&`87`
M="F-5"0LZ%SM__^%P'3H@#@`=..#[`Q0Z$K#__^#Q!"%P'33B</INOO__[@-
M````NQ/?!`CIN_O__Y"-="8`BT0D$(L8Z6?^__]J`FK_:NZ+="0D5N@-PO__
M@\0,:@:-A"0D`0``4%;HNL#__X/$$("\)!P!````=0Z`O"0=`0``0P^$;08`
M`&H`:@!J`/]T)"3HT,'__\=$)'`!(T5GQT0D=`````#'1"1XB:O-[\=$)'P`
M````QX0D@````/[<NIC'A"2$`````````,>$)(@```!V5#(0QX0DC```````
M``#'A"20````\.'2P\>$))0`````````QX0DF`````````#'A"2<````````
M`,>$)*``````````QX0DI`````````#'A"3H`````````(/$$(EL)!R#[`1H
M`(```(V$)"0!``!0_W0D).C7O___@\00A<")PP^.`P(``(NT)(@```"+O"2,
M````B=B9P>`#B5PD$(E4)!0!\(/_``^'PP$``#G&#X>[`0``B[0DD````(N\
M))0```"+5"04B80DB````(M$)!#'A"2,``````````^LT!W!ZAT!QHN$)-@`
M```1UXFT))````")O"24````A<`/A%L!``"Z0````(G>*<(YTWX"B=:-C"28
M````@^P$5@'(C8PD)`$``%%0Z&&___^+A"3H`````?")A"3H````@\00@_A`
M#X45____C80D'`$``"GSC2PPC40D8.C0Q?__@_L_#XXS!```@^M`B=_![P:-
M=P'!Y@8![HVT)@````"+10"#Q4")A"28````BT7$B80DG````(M%R(F$)*``
M``"+1<R)A"2D````BT70B80DJ````(M%U(F$)*P```"+1=B)A"2P````BT7<
MB80DM````(M%X(F$)+@```"+1>2)A"2\````BT7HB80DP````(M%[(F$),0`
M``"+1?")A"3(````BT7TB80DS````(M%^(F$)-````"+1?R)A"34````C40D
M8.@$Q?__.>X/A4S____!YP8I^VI$4U:-A"2D````4.BFO___B9PDZ````(/$
M$.D'_O__C;0F`````(VL)!P!``#I]/[__XUT)@"+M"20````B[PDE````(/&
M`8/7`.DZ_O__BVPD'(/L#/]T)"3H1\'__XN$)*````"+E"2D````BYPDF```
M`(NT))P```")1"0@B50D)(G8B?(/K-`#@^`_C5`!QH0$J````("#Q!"#^C@/
MC\0"``"X.````(V,))@````IT`'*@_@$#X/J`@``A<!T"Z@"Q@(`#X6I`P``
MBU0D%(M$)!"(G"37````#ZS0&(M4)!2(A"30````BT0D$`^LT!"+5"04B(0D
MT0```(M$)!`/K-`(B?*(A"32````#[9$)!"(A"33````B=@/K-`8B?*(A"34
M````B=@/K-`0B?*(A"35````B=@/K-`(B(0DU@```(U$)&#HI\/__XM,)&"+
M7"1DB<Z)WXB,).(````/K/X8B=^)\(G.#ZS^$(G?B(0DWP```(GRB<Z+3"1H
M#ZS^"(B4).````")\XG.B(PDY@```(B<).$```"+7"1LB=\/K/X8B=^)\HG.
M#ZS^$(B4).,```")WXGRB<Z+3"1P#ZS^"(B4).0```")\XG.B(PDZ@```(B<
M).4```"+7"1TB=\/K/X8B=^)\HG.#ZS^$(B4).<```")WXGRB<Z+3"1X#ZS^
M"(B4).@```")\XG.B(PD[@```(B<).D```"+7"1\B=\/K/X8B=^)\HG.#ZS^
M$(B4).L```")WXGRB<Z+C"2`````#ZS^"(B4).P```")\XG.B(PD\@```(B<
M).T```"+G"2$````B=\/K/X8B=^)\HG.#ZS^$(B4).\```")WXGRB<X/K/X(
MB)0D\````(V\)/,```")\XVT).````"(G"3Q````C9PD&P$``.D+````D(UT
M)@`/M@:#Q@&#[`P/ML!0:#3?!`AJ_VH!5X/'`NCYOO__@\0@.?MUVL:$)!L!
M````:(7?!`B-A"3W````4&@<W@0(_W0D&&A1WP0(:O]J`57HQ;[__X/$(.EO
M^?__BT0D$(M0!(72#X2V^/__@^P,4HE4)"#HP;S__X/$$(/X`P^&G?C__XM4
M)!"_3-\$"+D%````C70"_/.F#X6#^/__B=/I?/C__XGNZ9;\__^-C"28````
MN$`````!T2G0B<)T#3'`Q@0!`(/``3G0<O6-1"1@C;PDF````.A<P?__N0X`
M```QP/.KZ27]__^-2@3'`@````#'1`+\`````(/A_"G*`<*#XOR#^@0/@@']
M__^#XOPQP,<$`0````"#P`0YT'+RZ>G\__^`O"0>`0``00^%A?G__X"\)!\!
M``!##X5W^?__@+PD(`$``$@/A6GY__^`O"0A`0``10^%6_G__VH":O]JQHMT
M)"16Z"J[__^#Q`QJ*8V$)"0!``!05NC7N?__:(7?!`B-A"0P`0``4&@<W@0(
M_W0D*&A1WP0(:O]J`57H<KW__X/$,.D<^/__C78`C;PG`````#')9HE,`O[I
M2_S__^@ONO__ZPV0D)"0D)"0D)"0D)"055=64X/L*&6A%````(E$)!@QP/\U
M,$$%".C2O/__C50D&,9`90&X/]X$".B0Y?__@\00A<!T"8`X,0^$4`(``.B[
M[___@^P,_S4P004(Z)V\__]J"VH!:'_?!`A0Z*ZZ__^#Q""%P`^$LP```(,]
M:%$%"`&+0`R+>!@/CJ`````Q]KL!````ZS&-M"8`````BT4,@^P(4*%D404(
M_S28Z,RX__^#Q!"%P'5EH6A1!0B#PP&#Q@$YV'Y;@^P,_S4P004(Z"B\__]J
M`%974.B>N___@\0@A<!T-XLHBT4()0`$(``]``0``'2F@^P,_S4P004(Z/B[
M__]J`FH`55#HC;G__X/$(.N+D(VT)@````"A:%$%"(U0_SGR#X0P`0``@^P,
M_S4P004(Z,*[__]J`VH!:(3?!`A0Z-.Y__^#Q""%P(G#=#2+0`R#[`R+,/\U
M,$$%".B7N___@\0,:(;?!`A64.@8N?__BT,,@\00BQCV0PI`#X40`@``@^P,
M_S4P004(Z&B[__]J`VH!:(O>!`A0Z'FY__^#Q""%P(G&=#F-5"0(N`W>!`CH
M$N3__X7`B<,/A&@!``"+1@R#[`R+./\U,$$%".@EN___@\0,4U=0Z*JX__^#
MQ!"#[`S_-3!!!0CH";O__XU4)!C&0&4`N`3>!`CHQ^/__X/$$(7`B<.C;%$%
M"`^$E0```(/L"&C``0``4.B7N?__C5`!@\00@_H!=@F#^!$/A8X!``"+1"0,
M93,%%`````^%>`$``(/$'%M>7UW#C78`C;PG`````(/X`0^.Q_[__[L!````
M9I"#[`S_-3!!!0B#PP'H?[K__UY=5U#H5K?__X/$$#D=:%$%"'_;Z9;^__^-
MM@````"`>`$`#X2K_?__Z:']__^0@^P,_S5D404(Z.+P__^#Q!"%P*-L404(
M#X3K````BT8,BSUD404(BQB+0P@E``0@`#T`!```#X6-````BT,,@^P(5U#H
M=[?__XG'BT8,@\00BQB+0P@E``0@`#T`!```=4F+0PQ74*%D404(_S!H>.`$
M".AXN/__D(VT)@````"A9%$%"(/L#(LXBT8,BQC_-3!!!0CHMKG__XGZB=CH
MS>?__X/$$.F._O__@^P,_S4P004(Z)>Y__]J`FH`4U#H++?__X/$(.N<@^P,
M_S4P004(Z'FY__]J`FH`4U#H#K?__X/$(.E5____@^P,_S4P004(Z%BY__]:
M65-0Z&^X__^#Q!#IT?W__X/L#&A4X`0(Z-JW___H9;;__U"A9%$%"%/_,&B@
MX`0(Z,*W__]FD%93@^P0BW0D'%;H,>O__P^V$(/$$(G#A-)T((U``>L*#[80
M@\`!A-)T$8#Z+W7Q#[80B<.#P`&$TG7OZ+#M__^%]G0>A<!T&H`^`'05@^P(
M:#G?!`A3Z#6U__^#Q!`YV'0&@\0$6U[#@\0$B?!;7NG,Y/__9I!FD&:09I!F
MD&:04^@ZN___@</Z8@``@^P(_[,,`0``_W0D'/]T)!S_="0<Z#JV__^#Q!A;
MPV:09I"055<Q_U93Z`6[__^!P\5B``"#[`R+;"0@C;/D_O__Z(FT__^-@^#^
M__\IQL'^`H7V=".-M@````"#[`3_="0L_W0D+%7_E+O@_O__@\<!@\00.?=U
MXX/$#%M>7UW#C78`\\,``%.#[`CHH[K__X'#8V(``(/$"%O#`P````$``@`E
M<R\E<P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D
M97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O)6DO)7,`+@!005)?5$5-
M4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`
M4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`
M4$%27T1%0E5'`%!!4E]#04-(10!005)?05)'0P!005)?05)'5E\P`%!!4E]'
M3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?
M1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$E"
M4$%42`!$64Q$7TQ)0E)!4EE?4$%42`!32$Q)0E]0051(`%5315(`4UE35$5-
M`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R>`!P87(M`"5S)7,E<R5S
M`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T
M96UP+25U+25U)7,`05)'5@`8`'!E<FP`+64`+2T`````7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("``````<&5R;'AS:2YC````)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H
M<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&5X96-U
M=&EO;B!O9B`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H`````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K
M(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP
M86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T
M;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@
M1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P
M87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@
M*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?
M=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2![
M"FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A8
M6%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I
M+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M
M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M
M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H
M96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@
M)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^
M9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O
M;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H
M<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z
M.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FEF("AE>&ES=',@)$5.
M5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*0$%21U8@
M/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'
M0WT@+2`Q*3L*)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PIF;W(@
M*&ME>7,@)45.5BD@>PID96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O
M.PI]"GT*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I
M9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@
M/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA
M;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?
M<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?
M1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@
M)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U
M,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE
M(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R
M(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D
M;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@
M9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D
M;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA
M<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E
M="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D
M:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F
M9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E
M="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*
M)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0[
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B
M+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L
M("1C<F,I.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T
M("1B=68["F-L;W-E("1O=70["F-H;6]D(#`W-34L("1F:6QE;F%M93L*?0HD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E
M9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`]("(D14Y6
M>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*;W5T<R@B4TA,24(Z("1F:6QE
M;F%M95QN(BD["F]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE
M("0A.PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O
M=70["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z
M.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U
M9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@
M7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF
M+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M
M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M
M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER
M95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@
M)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F
M:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO
M861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@
M86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&
M:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I
M;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T
M=7)N("1F:#L*?0IE;'-E('L*;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL
M92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["FEF("@D;W5T*2!["F)I;FUO
M9&4H)&]U="D["G!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*8VQO<V4@
M)&]U=#L*?0IO<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["F)I
M;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@
M9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI
M;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;
M,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^
M("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR
M97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S
M<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE
M=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B
M=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H
M+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C
M('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD
M<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T
M7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T
M*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I
M;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@
M('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR
M975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S
M:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*
M;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O
M7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@
M)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N
M<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O
M=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET
M92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*
M96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E
M<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#
M86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C
M86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]
M("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN
M:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C
M;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I
M(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I
M;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY
M("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#
M:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R
M(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@
M97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]
M?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A
M(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@
M9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO
M="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]
M"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD
M;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*
M8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A
M=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@
M<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO
M861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L
M>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@
M979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?
M14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B
M("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K
M*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG
M=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U
M;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I
M<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@<V]R="!["FQE;F=T:"@D8BD@/#T^
M(&QE;F=T:"@D82D*?2!G<F5P('L*(2]"4T1004XO"GT@9W)E<"!["B@D8G5N
M9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]
M*3L*?2!`24Y#.PIM>2`E9FEL97,["B]>7SPH+BLI)"\@86YD("UE("0Q(&%N
M9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PHD9FEL97-[)%]]*RL@9F]R
M('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML
M:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL
M97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN
M8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@
M>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ
M6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S
M=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*
M:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H
M+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@
M)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N
M9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@
M86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B
M+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE
M*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&
M24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B
M.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,
M13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T
M<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I
M.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD
M9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC
M;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP
M86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT
M96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II
M<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII
M9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;
M.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$
M:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R
M<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII
M9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@
M)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D[
M"GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI
M('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F
M:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@
M.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^
M<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M
M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N
M<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]
M"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N
M86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I
M(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE
M("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,
M:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO
M=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X
M="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@
M)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[
M4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@
M)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T
M<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y
M(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%
M>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD
M;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D
M*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*
M=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B
M+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)
M9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!=
M"B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*
M<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I
M;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q
M=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N
M;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U
M8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA
M3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U
M:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P[
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N
M9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@
M4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D
M('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C
M86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ
M0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U
M<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ
M<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P
M87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R
M;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!
M4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<
M5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A
M;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P
M=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE
M9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD
M=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE
M9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E
M<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-4
M14TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B
M)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N
M86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%
M04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO
M<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@
M,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!
M0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@
M-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ
M340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z
M.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N
M,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL
M92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T
M>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D
M9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C
M='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS
M92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER
M.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D
M,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&5X="P@)&-R8RD@/2!`7SL*
M;7D@*"1F:"P@)&9I;&5N86UE*3L*)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D
M8W)C)&5X="(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*=6YL:6YK("1F:6QE
M;F%M92!I9B`M92`D9FEL96YA;64["G!U<V@@0'1M<&9I;&4L("1F:6QE;F%M
M93L*?0IE;'-E('L*<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@
M)&9I;&5N86UE*3L*?0IO<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE
M("0A.PIB:6YM;V1E*"1F:"D["G)E='5R;B@D9F@L("1F:6QE;F%M92D["GT*
M<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'
M3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R
M;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%2
M7U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^
M/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[
M4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE
M*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N
M9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T
M=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A
M=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6
M>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]
M?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA
M<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G
M;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D
M("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97
M:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO
M;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?
M9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H
M("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E
M;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!3
M4$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!
M4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W
M+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1?
M?2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!
M4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?
M0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@
M>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%
M3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P
M87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%
M04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]
M"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP
M<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*
M?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G
M<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C
M:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N
M9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E
M<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2
M+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E
M;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I
M<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64[
M"D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI
M+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]
M"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<
M*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*
M7U]%3D1?7PH```$;`SO8````&@```&AS___T````>'?__QP-``!X>O__&`$`
M`-B?__]<`0``B*#__\`!```(H?__Y`$``"BC__]D`@``B*3__QP#```HI?__
M>`,``.BE__\4!```&*;__SP$``!HIO__=`0``"BG__\`!0``.*?__Q0%``#X
MJ/__$`8``"BI__\D!@``&*K__X0&``#8J___M`8``$BL___0!@``>*S___0&
M``"HK?__9`<``!BZ__]`"P``Z+W__]`,``!HOO__7`T``)B^__^(#0``^+[_
M_]0-```4``````````%Z4@`!?`@!&PP$!(@!```@````'````&QR__\`!```
M``X(1@X,2@\+=`1X`#\:.RHR)")`````0````%AY__]<)0```$$."(4"00X,
MAP-$#A"&!$$.%(,%1@Z@!@-%)0H.%$'##A!!Q@X,0<<."$'%#@1!"P```&``
M``"$````=)[__Z8`````20X(A0)!#@R'`T$.$(8$00X4@P5##C`"1`XT00XX
M00X\00Y`2`XP5PH.%$/##A!!Q@X,0<<."$'%#@1%"UH.%$7##A!!Q@X,0<<.
M"$'%#@0````@````Z````,">__]R`````$$."(,"10X@`F4*#@A!PPX$00M\
M````#`$``!R?__\8`@```$$."(4"00X,AP-##A"&!$$.%(,%10Y,5PY02`Y`
M6`Y,0PY02`Y``DL.3$<.4$H.0`)T"@X40<,.$$'&#@Q!QPX(0<4.!$<+`E`.
M2$$.3$$.4$@.0&T.3$L.4$@.0$X.1$$.2$D.3$4.4$P.0````+0```",`0``
MO*#__U8!````00X(A0)!#@R'`T$.$(8$00X4@P5(#J`!;`H.%$'##A!!Q@X,
M0<<."$'%#@1$"T,.K`%!#K`!2`Z@`4\.K`%!#K`!2`Z@`5<.K`%$#K`!9`ZL
M`4$.J`%!#JP!00ZP`44.M`%"#K@!0@Z\`4$.P`%(#J0!10ZH`4$.K`%"#K`!
M2`Z@`5@.K`%!#K`!2`Z@`4,.K`%!#K`!2`Z@`78.K`%!#K`!4`Z@`0!8````
M1`(``&2A__^1`````$$."(,"10X<1@X@2`X41@X800X<0@X@2`X01PH."$/#
M#@1!"T,.'$8.($X.$$\.'$8.($X.$$\.&$(.'$$.($@.$$@."$3##@0``)@`
M``"@`@``J*'__[L`````00X(A0)!#@R'`T,.$(8$00X4@P5(#K0@5`ZX($4.
MO"!%#L`@2`ZP(%,.M"!!#K@@0@Z\($$.P"!(#K`@1PZ\($8.P"!&#L0@00[(
M($$.S"!!#M`@2`ZP(%8*#A1!PPX00<8.#$''#@A!Q0X$10M+#KP@1@[`($@.
MM"!!#K@@00Z\($$.P"!(#K`@`"0````\`P``S*'__R<`````0PX<1@X@2@XD
M10XH10XL00XP2`X$```T````9`,``-2A__]$`````$,.'$8.($X.'$8.($8.
M'$$.&$(.'$4.($4.)$4.*$4.+$$.,$@.!(@```"<`P``[*'__[$`````00X(
MAP)!#@R&`T$.$(,$1@Z@0%<.J$!%#JQ`00ZP0$4.M$!%#KA`0@Z\0$4.P$!(
M#J!`1PZD0$4.J$!(#JQ`00ZP0$@.H$!,#JQ`00ZP0$@.H$!)#J1`00ZH0$$.
MK$!!#K!`3`Z@0%@*#A!!PPX,0<8."$''#@1$"P``$````"@$```@HO__!0``
M``````#X````/`0``!RB__^X`0```$$."(4"00X,AP-!#A"&!$$.%(,%1@[`
M(&X.R"!$#LP@00[0($@.P"!L"@X40<,.$$'&#@Q!QPX(0<4.!$$+0P[,($$.
MT"!&#LP@00[(($D.S"!!#M`@2`[`(&L.R"!!#LP@00[0($@.P"!+#LP@00[0
M($@.P"!M#L0@00[(($4.S"!!#M`@10[4($4.V"!"#MP@00[@($@.S"!&#M`@
M2`[$($8.R"!!#LP@0@[0($@.P"!'#LP@1@[0($X.P"!/#L@@10[,($(.T"!(
M#L`@2@[(($(.S"!!#M`@2`[`(%,.S"!!#M`@2`[`(``0````.`4``."B__\M
M`````````%P```!,!0``_*+__^<`````00X(@P)##B!6#BQ!#C!,#B!L#BQ"
M#C!(#B!/"@X(0<,.!$,+8`H."$'##@1/"V$.)$$.*$$.+$4.,$@.($@*#@A!
MPPX$1PM##@A#PPX$`"P```"L!0``C*/__[<!````00X(AP)!#@R&`T,.0`-;
M`0H.#$'&#@A!QPX$1@L``!@```#<!0``'*7__VD`````0PX@9@H.!$<+```@
M````^`4``'"E__\D`````$,.$$@.'$$.($@.$$D*#@1#"P!L````'`8``'RE
M__\F`0```$$."(4"00X,AP-&#A"&!$$.%(,%2`Y@`E(.:$$.;$$.<$P.8`)"
M"@X40<,.$$'&#@Q!QPX(0<4.!$D+0PYL00YP;`YD10YH10YL00YP10YT0@YX
M0@Y\00Z``4P.8```V`,``(P&```\IO__80P```!!#@B%`D$.#(<#00X0A@1!
M#A2#!48.P(("`J<.S(("00[0@@),#L""`D,.S(("00[0@@)(#L""`E0.S(("
M1`[0@@)%#M2"`D(.V(("0@[<@@)!#N""`DL.P(("`D,.S(("00[0@@)(#L""
M`@)##LR"`D$.T(("2`[`@@)6#LR"`D,.T(("2`[`@@)O#LR"`DH.T(("2@[4
M@@)'#MB"`D4.W(("00[@@@)%#N2"`D(.Z(("0@[L@@)!#O""`D@.R(("10[,
M@@)!#M""`D@.P(("2`[,@@)&#M""`D@.Q(("1@[(@@)$#LR"`D(.T(("2`[`
M@@)'#LR"`D0.T(("1@[4@@)%#MB"`D(.W(("1@[@@@)(#L""`EP*#A1!PPX0
M0<8.#$''#@A!Q0X$2`M/"@[(@@)!#LR"`D0.T(("1@[4@@)%#MB"`DD+0P[,
M@@)&#M""`DX.P(("4P[,@@)&#M""`E,.P(("2P[,@@)&#M""`DX.P(("4P[,
M@@)!#M""`E@.P(("2P[,@@)!#M""`D8.S(("00[(@@)!#LR"`D8.T(("2`[`
M@@)-#LR"`D$.T(("2`[`@@)^#LB"`D(.S(("00[0@@),#L""`F,.Q(("00[(
M@@)%#LR"`D4.T(("10[4@@)"#MB"`D(.W(("00[@@@)(#L""`EH.S(("10[0
M@@)!#M2"`D$.V(("10[<@@)!#N""`D4.Y(("0@[H@@)"#NR"`D$.\(("2`[`
M@@)##LB"`D4.S(("00[0@@)(#L""`D@.S(("1`[0@@)<#L""`DX.S(("00[0
M@@)8#L""`G0.S(("00[0@@)(#L""`FP.Q(("0@[(@@)"#LR"`D4.T(("2`[$
M@@)"#LB"`D@.S(("00[0@@)(#L""`EH.Q(("0@[(@@)"#LR"`D0.T(("`J$.
MP(("1P[$@@)%#LB"`D@.S(("1`[0@@)(#L""`@*B#L2"`D$.R(("2@[,@@)!
M#M""`E@.P(("`OD.Q(("00[(@@)!#LR"`D@.T(("3P[`@@)\#LR"`D0.T(("
M`D(.P(("`RL"#LR"`D0.T(("10[4@@)"#MB"`D(.W(("00[@@@)+#L""`E$.
MQ(("2`[(@@)%#LR"`D0.T(("10[4@@)"#MB"`D(.W(("00[@@@)(#L""`E<.
MS(("00[0@@),#L""`@+F#L2"`D(.R(("0@[,@@)%#M""`D@.Q(("0@[(@@)(
M#LR"`D$.T(("2@[4@@)(#MB"`D4.W(("1`[@@@)%#N2"`D(.Z(("0@[L@@)!
M#O""`D@.P(("`(P!``!H"@``T*[__\X#````00X(A0)!#@R'`T$.$(8$00X4
M@P5##CQ2#D!:#C!5#CQ&#D!'#D1"#DA%#DQ!#E!(#C!Q#CA!#CQ(#D!(#C!6
M#CQ&#D!'#D1!#DA!#DQ!#E!(#C!8#CQ&#D!'#D1"#DA!#DQ!#E!(#C!=#CQ&
M#D!'#D1"#DA%#DQ!#E!(#C!,#CQ(#D!(#C1%#CA!#CQ!#D!+#C!/#CQ&#D!'
M#D1"#DA%#DQ!#E!(#C!D#CQ(#D!(#C1!#CA!#CQ!#D!(#C!##CQ&#D!:#C!2
M#CA%#CQ!#D!+#C!B"@X40<,.$$'&#@Q!QPX(0<4.!$L+4PX\1@Y`20X\00XX
M00X\00Y`2`XP9@X\1@Y`2`XP<0XX00X\00Y`30XP50H.-$$..$<./$4.0$T+
M2`X\30Y`40XP2`X\1@Y`1PY$0@Y(00Y,00Y02`XP10X\1@Y`1PY$0@Y(00Y,
M00Y02`XP2`X\1@Y`1@X\00XX00X\00Y`2`XP2`H./$4.0$4+1@XT1@XX0@X\
M10Y```!(````^`L``!"Q__]T`````$$."(8"00X,@P-##AQ%#B!+#A![#AA%
M#AQ!#B!(#A!'"@X,0<,."$'&#@1!"T,.#$/##@A!Q@X$````/````$0,``!4
M:O__"@(```!$#`$`1Q`%`G4`10\#=70&$`8"=7P0`P)U>`.+`0K!#`$`0<-!
MQD'%0PP$!$$+`"@```"$#```!+'__RL`````00X(@P).#A!&#A1$#AA$#AQ$
M#B!(#@A!PPX$2````+`,```(L?__70````!!#@B%`D$.#(<#0PX0A@1!#A2#
M!4X.(&<.)$0.*$0.+$$.,$T.($<.%$'##A!!Q@X,0<<."$'%#@0``!````#\
M#```'+'__P(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#@F`0(P)@$
M"``````!`````0````$```#3`0```0```-X!```!````Z`$```$````W`@``
M`0```(P#```,````W)$$"`T```"4W00(&0```.`^!0@;````!````!H```#D
M/@4('`````0```#U_O]OK($$"`4```!DB00(!@````2#!`@*````\@0```L`
M```0````%0`````````#`````$`%"`(```#X`0``%````!$````7````Y(\$
M"!$```"TCP0($@```#`````3````"````/[__V\DCP0(____;P(```#P__]O
M5HX$"```````````````````````````````````````````````````````
M``````````````#L/@4(```````````6D@0()I($"#:2!`A&D@0(5I($"&:2
M!`AVD@0(AI($"):2!`BFD@0(MI($",:2!`C6D@0(YI($"/:2!`@&DP0(%I,$
M"":3!`@VDP0(1I,$"%:3!`AFDP0(=I,$"(:3!`B6DP0(II,$"+:3!`C&DP0(
MUI,$".:3!`CVDP0(!I0$"!:4!`@FE`0(-I0$"$:4!`A6E`0(9I0$"':4!`B&
ME`0(EI0$"*:4!`BVE`0(QI0$"-:4!`CFE`0(]I0$"`:5!`@6E00()I4$"#:5
M!`A&E00(5I4$"&:5!`AVE00(AI4$"):5!`BFE00(MI4$",:5!`C6E00(YI4$
M"/:5!`@``````````/_____DX`0(1T-#.B`H1&5B:6%N(#4N,RXQ+34I(#4N
M,RXQ(#(P,38P,3`Q`$=#0SH@*$1E8FEA;B`T+CDN,RTQ,"D@-"XY+C,``"YS
M:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD
M+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG
M;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YP;'0N9V]T
M`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`
M+FEN:71?87)R87D`+F9I;FE?87)R87D`+FIC<@`N9'EN86UI8P`N9V]T+G!L
M=``N9&%T80`N8G-S`"YC;VUM96YT````````````````````````````````
M```````````````````````+`````0````(```!4@00(5`$``!,`````````
M``````$`````````$P````<````"````:($$"&@!```@```````````````$
M`````````"$````'`````@```(B!!`B(`0``)```````````````!```````
M```T````]O__;P(```"L@00(K`$``%@!```%``````````0````$````/@``
M``L````"````!(,$"`0#``!@!@``!@````$````$````$````$8````#````
M`@```&2)!`AD"0``\@0``````````````0````````!.````____;P(```!6
MC@0(5@X``,P````%``````````(````"````6P```/[__V\"````)(\$""0/
M``"0````!@````(````$`````````&H````)`````@```+2/!`BT#P``,```
M``4`````````!`````@```!S````"0```$(```#DCP0(Y`\``/@!```%````
M&`````0````(````?`````$````&````W)$$"-P1```C```````````````$
M`````````'<````!````!@````"2!`@`$@````0`````````````$`````0`
M``""`````0````8`````E@0(`!8```@```````````````@`````````BP``
M``$````&````$)8$"!`6``""1P`````````````0`````````)$````!````
M!@```)3=!`B470``%```````````````!`````````"7`````0````(```"H
MW00(J%T``/!```````````````0`````````GP````$````"````F!X%")B>
M``#<```````````````$`````````*T````!`````@```'0?!0ATGP``$`T`
M````````````!`````````"W````#@````,```#@/@4(X*X```0`````````
M``````0`````````PP````\````#````Y#X%".2N```$```````````````$
M`````````,\````!`````P```.@^!0CHK@``!```````````````!```````
M``#4````!@````,```#L/@4([*X``!`!```&``````````0````(````A@``
M``$````#````_#\%"/RO```$```````````````$````!````-T````!````
M`P````!`!0@`L```"`$`````````````!`````0```#F`````0````,````(
M004("+$``!````````````````0`````````[`````@````#````($$%"!BQ
M``!4$``````````````@`````````/$````!````,``````````8L0``0@``
M`````````````0````$````!`````P``````````````6K$``/H`````````
,``````$`````````
